searchData={"items":[{"type":"module","title":"GraphQLWSClient","doc":"An extensible client for connecting to GraphQL websockets that are implemented\nfollowing\nthe [graphql-ws](https://github.com/enisdenjo/graphql-ws) conventions.","ref":"GraphQLWSClient.html"},{"type":"module","title":"Example - GraphQLWSClient","doc":"Send a query or mutation and return the result immediately:\n\n    {:ok, result} = GraphQLWSClient.query(socket, \"query GetPost { ... }\")\n\nRegister a subscription to listen for events:\n\n    {:ok, subscription_id} = GraphQLWSClient.subscribe(\n      socket,\n      \"subscription PostCreated { ... }\"\n    )\n\n    GraphQLWSClient.query!(socket, \"mutation CreatePost { ... }\")\n\n    receive do\n      %GraphQLWSClient.Event{type: :error, id: ^subscription_id, payload: error} ->\n        IO.inspect(error, label: \"error\")\n      %GraphQLWSClient.Event{type: :next, id: ^subscription_id, payload: result} ->\n        IO.inspect(result)\n      %GraphQLWSClient.Event{type: :complete, id: ^subscription_id} ->\n        IO.puts(\"Stream closed\")\n    end\n\n    GraphQLClient.close(socket)\n\nYou would usually put this inside of a custom `GenServer` and handle the events\nin `handle_info/3`.\n\nAlternatively, you can create a stream of results:\n\n    socket\n    |> GraphQLWSClient.stream!(\"subscription PostCreated { ... }\")\n    |> Stream.each(fn result ->\n      IO.inspect(result)\n    end)\n    |> Stream.run()","ref":"GraphQLWSClient.html#module-example"},{"type":"module","title":"Custom Client - GraphQLWSClient","doc":"If you want to run the client as part of a supervision tree in your\napplication, you can also `use GraphQLWSClient` to create your own client.\n\n    defmodule MyClient do\n      use GraphQLWSClient, otp_app: :my_app\n    end\n\nThen, you can configure your client using a config file:\n\n    import Config\n\n    config :my_app, MyClient,\n      url: \"ws://localhost:4000/socket\"\n\nSee `GraphQLWSClient.Config.new/1` for a list of available options.","ref":"GraphQLWSClient.html#module-custom-client"},{"type":"function","title":"GraphQLWSClient.child_spec/1","doc":"The default child specification that can be used to run the client under a\nsupervisor.","ref":"GraphQLWSClient.html#child_spec/1"},{"type":"function","title":"GraphQLWSClient.close/1","doc":"Closes the connection to the websocket.","ref":"GraphQLWSClient.html#close/1"},{"type":"function","title":"GraphQLWSClient.connected?/1","doc":"Indicates whether the client is connected to the Websocket.","ref":"GraphQLWSClient.html#connected?/1"},{"type":"function","title":"GraphQLWSClient.open/1","doc":"Opens the connection to the websocket.","ref":"GraphQLWSClient.html#open/1"},{"type":"function","title":"GraphQLWSClient.open!/1","doc":"Opens the connection to the websocket. Raises on error.","ref":"GraphQLWSClient.html#open!/1"},{"type":"function","title":"GraphQLWSClient.open_with/2","doc":"Opens the connection to the websocket using a custom payload.","ref":"GraphQLWSClient.html#open_with/2"},{"type":"function","title":"GraphQLWSClient.open_with!/2","doc":"Opens the connection to the websocket using a custom payload. Raises on error.","ref":"GraphQLWSClient.html#open_with!/2"},{"type":"function","title":"GraphQLWSClient.query/4","doc":"Sends a GraphQL query or mutation to the websocket and returns the result.","ref":"GraphQLWSClient.html#query/4"},{"type":"function","title":"Example - GraphQLWSClient.query/4","doc":"iex> GraphQLWSClient.query(\n    ...>   client,\n    ...>   \"query GetPost($id: ID!) { post(id: $id) { body } }\",\n    ...>   %{\"id\" => 1337}\n    ...> )\n    {:ok, %{\"data\" => %{\"posts\" => %{\"body\" => \"Lorem Ipsum\"}}}}","ref":"GraphQLWSClient.html#query/4-example"},{"type":"function","title":"GraphQLWSClient.query!/3","doc":"Sends a GraphQL query or mutation to the websocket and returns the result.\nRaises on error.","ref":"GraphQLWSClient.html#query!/3"},{"type":"function","title":"Example - GraphQLWSClient.query!/3","doc":"iex> GraphQLWSClient.query!(\n    ...>   client,\n    ...>   \"query GetPost($id: ID!) { post(id: $id) { body } }\",\n    ...>   %{\"id\" => 1337}\n    ...> )\n    %{\"data\" => %{\"posts\" => %{\"body\" => \"Lorem Ipsum\"}}}","ref":"GraphQLWSClient.html#query!/3-example"},{"type":"function","title":"GraphQLWSClient.start_link/1","doc":"Starts a GraphQL Websocket client.","ref":"GraphQLWSClient.html#start_link/1"},{"type":"function","title":"Options - GraphQLWSClient.start_link/1","doc":"See `GraphQLWSClient.Config.new/1` for a list of available options.\nAdditionally, you may pass `t:GenServer.options/0`.","ref":"GraphQLWSClient.html#start_link/1-options"},{"type":"function","title":"GraphQLWSClient.start_link/2","doc":"Starts a GraphQL Websocket client using the given config and `GenServer`\noptions.","ref":"GraphQLWSClient.html#start_link/2"},{"type":"function","title":"Options - GraphQLWSClient.start_link/2","doc":"The first argument accept options as specified in\n`GraphQLWSClient.Config.new/1`. The second argument accepts\n`t:GenServer.options/0`.","ref":"GraphQLWSClient.html#start_link/2-options"},{"type":"function","title":"GraphQLWSClient.stream!/4","doc":"Sends a GraphQL subscription to the websocket and returns an event stream.","ref":"GraphQLWSClient.html#stream!/4"},{"type":"function","title":"Options - GraphQLWSClient.stream!/4","doc":"* `:buffer_size` - Sets the buffer size. If the buffer is exceeded, the oldest\n  events are discarded first. Although it is not recommended, you may also set\n  the value to `:infinity` to set no limit. Defaults to `1000`.","ref":"GraphQLWSClient.html#stream!/4-options"},{"type":"function","title":"Example - GraphQLWSClient.stream!/4","doc":"iex> stream = GraphQLWSClient.stream!(\n    ...>   client,\n    ...>   \"\"\"\n    ...>     subscription CommentAdded($postId: ID!) {\n    ...>       commentAdded(postId: $postId) { body }\n    ...>     }\n    ...>   \"\"\",\n    ...>   %{\"postId\" => 1337}\n    ...> )\n\nPrint events as they come in:\n\n    iex> stream\n    ...> |> Stream.each(fn result -> IO.inspect(result) end)\n    ...> |> Stream.run()\n\nWait for a fixed number of events to come in and then turn them into a list:\n\n    iex> stream |> Stream.take(3) |> Enum.to_list()","ref":"GraphQLWSClient.html#stream!/4-example"},{"type":"function","title":"GraphQLWSClient.subscribe/4","doc":"Sends a GraphQL subscription to the websocket and registers a listener process\nto retrieve events.","ref":"GraphQLWSClient.html#subscribe/4"},{"type":"function","title":"Example - GraphQLWSClient.subscribe/4","doc":"iex> GraphQLWSClient.subscribe(\n    ...>   client,\n    ...>   \"\"\"\n    ...>     subscription CommentAdded($postId: ID!) {\n    ...>       commentAdded(postId: $postId) { body }\n    ...>     }\n    ...>   \"\"\",\n    ...>   %{\"postId\" => 1337}\n    ...> )\n    {:ok, \"767f051c-63b7-4dd1-8d7a-af91f0ccaa71\"}","ref":"GraphQLWSClient.html#subscribe/4-example"},{"type":"function","title":"GraphQLWSClient.subscribe!/4","doc":"Sends a GraphQL subscription to the websocket and registers a listener process\nto retrieve events. Raises on error.","ref":"GraphQLWSClient.html#subscribe!/4"},{"type":"function","title":"Example - GraphQLWSClient.subscribe!/4","doc":"iex> GraphQLWSClient.subscribe!(\n    ...>   client,\n    ...>   \"\"\"\n    ...>     subscription CommentAdded($postId: ID!) {\n    ...>       commentAdded(postId: $postId) { body }\n    ...>     }\n    ...>   \"\"\",\n    ...>   %{\"postId\" => 1337}\n    ...> )\n    \"3f59edba-27ae-4015-9740-cfb73c91c270\"","ref":"GraphQLWSClient.html#subscribe!/4-example"},{"type":"function","title":"GraphQLWSClient.unsubscribe/2","doc":"Removes a subscription.","ref":"GraphQLWSClient.html#unsubscribe/2"},{"type":"function","title":"Example - GraphQLWSClient.unsubscribe/2","doc":"iex> GraphQLWSClient.unsubscribe(client, \"3f05c357-33a5-47ae-81d8-8da41b126126\")\n    :ok","ref":"GraphQLWSClient.html#unsubscribe/2-example"},{"type":"function","title":"GraphQLWSClient.unsubscribe!/2","doc":"Removes a subscription. Raises on error.","ref":"GraphQLWSClient.html#unsubscribe!/2"},{"type":"function","title":"Example - GraphQLWSClient.unsubscribe!/2","doc":"iex> GraphQLWSClient.unsubscribe!(client, \"0c50dab3-1f3e-45e1-9537-bb7561a2bca3\")\n    :ok","ref":"GraphQLWSClient.html#unsubscribe!/2-example"},{"type":"type","title":"GraphQLWSClient.client/0","doc":"Type for a client process.","ref":"GraphQLWSClient.html#t:client/0"},{"type":"type","title":"GraphQLWSClient.query/0","doc":"Type for a query, mutation or subscription string.","ref":"GraphQLWSClient.html#t:query/0"},{"type":"type","title":"GraphQLWSClient.subscription_id/0","doc":"Type for a subscription ID.","ref":"GraphQLWSClient.html#t:subscription_id/0"},{"type":"type","title":"GraphQLWSClient.variables/0","doc":"Type for variables that are interpolated into the query.","ref":"GraphQLWSClient.html#t:variables/0"},{"type":"module","title":"GraphQLWSClient.Config","doc":"A struct containing the configuration for a client.","ref":"GraphQLWSClient.Config.html"},{"type":"function","title":"GraphQLWSClient.Config.new/1","doc":"Builds a new config.","ref":"GraphQLWSClient.Config.html#new/1"},{"type":"function","title":"Options - GraphQLWSClient.Config.new/1","doc":"* `:backoff_interval` - The number of milliseconds to wait before trying to\n  reconnect to the server.\n\n* `:connect_on_start` - Determines whether to immediately connect to the\n  server as soon as the client is started. When set to `false`, you need to\n  manually connect by calling `GraphQLWSClient.open/1`. Defaults to `true`.\n\n* `:driver` - The driver module to use. Defaults to\n  `GraphQLWSClient.Drivers.Gun`. Can be either a module or a tuple in the form\n  of `{MyDriverModule, opt_a: \"hello world\"}`. The options are passed to the\n  driver's `init/1` callback, if defined.\n\n* `:host` - The host to connect to. This is ignored when `:url` is specified\n  instead.\n\n* `:init_payload` - The payload send together with the `connection_init`\n  message. Is useful when you need to authenticate a connection with a token,\n  for instance.\n\n* `:path` - The path on the server. This is ignored when `:url` is specified\n  instead. Defaults to `\"/\"`.\n\n* `:port` - The port to connect to. This is ignored when `:url` is specified\n  instead.\n\n* `:query_timeout` - The default query timeout in milliseconds. Defaults to\n  `5000`.\n\n* `:url` - The URL of the websocket to connect to. Overwrites the `:host`,\n  `:port` and `:path` options.","ref":"GraphQLWSClient.Config.html#new/1-options"},{"type":"type","title":"GraphQLWSClient.Config.t/0","doc":"","ref":"GraphQLWSClient.Config.html#t:t/0"},{"type":"module","title":"GraphQLWSClient.Event","doc":"A event for a subscription.\n\nThe struct consists of these fields:\n\n* `:payload` - Either the result, an error or `nil`, dependent on the `:type`\n  field.\n* `:subscription_id` - A UUID identifying the subscription. This matches the\n  subscription ID that is returned by `GraphQLWSClient.subscribe/3`.\n* `:type` - Indicates whether the event contains payload data (`:next`), there\n  is no more data to receive (`:complete`) or an error occurred (`:error`).","ref":"GraphQLWSClient.Event.html"},{"type":"type","title":"GraphQLWSClient.Event.complete/0","doc":"","ref":"GraphQLWSClient.Event.html#t:complete/0"},{"type":"type","title":"GraphQLWSClient.Event.error/0","doc":"","ref":"GraphQLWSClient.Event.html#t:error/0"},{"type":"type","title":"GraphQLWSClient.Event.next/0","doc":"","ref":"GraphQLWSClient.Event.html#t:next/0"},{"type":"type","title":"GraphQLWSClient.Event.t/0","doc":"","ref":"GraphQLWSClient.Event.html#t:t/0"},{"type":"module","title":"GraphQLWSClient.Conn","doc":"A struct passed to the used driver that contains information about the current\nconnection.","ref":"GraphQLWSClient.Conn.html"},{"type":"type","title":"GraphQLWSClient.Conn.t/0","doc":"","ref":"GraphQLWSClient.Conn.html#t:t/0"},{"type":"behaviour","title":"GraphQLWSClient.Driver","doc":"A behaviour that defines function to implement custom backends.","ref":"GraphQLWSClient.Driver.html"},{"type":"behaviour","title":"Customize Options - GraphQLWSClient.Driver","doc":"To customize the options that are used by the driver, you can set a custom\n`:driver` tuple when starting the client.\n\n    GraphQLWSClient.start_link(\n      host: \"example.com\",\n      driver: {GraphQLWSClient.Drivers.Gun, json_library: Poison},\n    )\n\nOr you can set it in the configuration for your custom client.\n\n    import Config\n\n    config :my_app, MyGraphQLWSClient,\n      driver: {GraphQLWSClient.Drivers.Gun, json_library: Poison}","ref":"GraphQLWSClient.Driver.html#module-customize-options"},{"type":"callback","title":"GraphQLWSClient.Driver.connect/1","doc":"Connects to the socket and returns the updated `GraphQLWSClient.Conn`.","ref":"GraphQLWSClient.Driver.html#c:connect/1"},{"type":"callback","title":"GraphQLWSClient.Driver.disconnect/1","doc":"Disconnects from the socket.","ref":"GraphQLWSClient.Driver.html#c:disconnect/1"},{"type":"callback","title":"GraphQLWSClient.Driver.init/1","doc":"Optional callback that prepares the `:opts` stored in the `GraphQLWSClient.Conn`.\nCan be used to set default values.","ref":"GraphQLWSClient.Driver.html#c:init/1"},{"type":"callback","title":"GraphQLWSClient.Driver.parse_message/2","doc":"Parses a message received from the socket.","ref":"GraphQLWSClient.Driver.html#c:parse_message/2"},{"type":"callback","title":"GraphQLWSClient.Driver.push_message/2","doc":"Pushes a message to the socket.","ref":"GraphQLWSClient.Driver.html#c:push_message/2"},{"type":"module","title":"GraphQLWSClient.Message","doc":"A low-level message sent and received by drivers.","ref":"GraphQLWSClient.Message.html"},{"type":"type","title":"GraphQLWSClient.Message.message_type/0","doc":"","ref":"GraphQLWSClient.Message.html#t:message_type/0"},{"type":"type","title":"GraphQLWSClient.Message.t/0","doc":"","ref":"GraphQLWSClient.Message.html#t:t/0"},{"type":"module","title":"GraphQLWSClient.Drivers.Gun","doc":"A driver using the `:gun` library to connect to the GraphQL websocket.","ref":"GraphQLWSClient.Drivers.Gun.html"},{"type":"module","title":"Usage - GraphQLWSClient.Drivers.Gun","doc":"The Gun driver is configured as default driver using Jason as default encoder\nand decoder. However, you still need to install the particular libraries\nyourself if you want to use them, so add these to your deps.\n\n    {:gun, \"~> 2.0\"},\n    {:jason, \"~> 1.4\"},","ref":"GraphQLWSClient.Drivers.Gun.html#module-usage"},{"type":"module","title":"Available Options - GraphQLWSClient.Drivers.Gun","doc":"See `GraphQLWSClient.Driver` to find out how to pass options to the driver.\n\n* `:ack_timeout` - The number of milliseconds to wait for a `connection_ack`\n  after initiating the connection. Defaults to `5000`.\n\n* `:connect_options` - Connection options forwarded to `:gun.open/3`. See\n  `t::gun.opts/0` for all available options.\n\n* `:json_library` - The library used to encode and decode JSON payloads.\n  `Jason` by default.\n\n* `:upgrade_timeout` - The number of milliseconds to wait for a connection\n  upgrade. Defaults to `5000`.","ref":"GraphQLWSClient.Drivers.Gun.html#module-available-options"},{"type":"exception","title":"GraphQLWSClient.GraphQLError","doc":"Exception that contains errors from a GraphQL query.","ref":"GraphQLWSClient.GraphQLError.html"},{"type":"function","title":"GraphQLWSClient.GraphQLError.message/1","doc":"","ref":"GraphQLWSClient.GraphQLError.html#message/1"},{"type":"type","title":"GraphQLWSClient.GraphQLError.t/0","doc":"","ref":"GraphQLWSClient.GraphQLError.html#t:t/0"},{"type":"exception","title":"GraphQLWSClient.OperationError","doc":"An error that indicates an invalid operation.","ref":"GraphQLWSClient.OperationError.html"},{"type":"exception","title":"GraphQLWSClient.SocketError","doc":"Exception that indicates a socket error.","ref":"GraphQLWSClient.SocketError.html"},{"type":"function","title":"GraphQLWSClient.SocketError.message/1","doc":"","ref":"GraphQLWSClient.SocketError.html#message/1"},{"type":"type","title":"GraphQLWSClient.SocketError.cause/0","doc":"","ref":"GraphQLWSClient.SocketError.html#t:cause/0"},{"type":"type","title":"GraphQLWSClient.SocketError.t/0","doc":"","ref":"GraphQLWSClient.SocketError.html#t:t/0"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2024 Tobias Casper\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Readme","doc":"# GraphQL Websocket Client\n\n[![Build](https://github.com/tlux/graphql_ws_client/actions/workflows/elixir.yml/badge.svg)](https://github.com/tlux/graphql_ws_client/actions/workflows/elixir.yml)\n[![Coverage Status](https://coveralls.io/repos/github/tlux/graphql_ws_client/badge.svg?branch=main)](https://coveralls.io/github/tlux/graphql_ws_client?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/graphql_ws_client.svg)](https://hex.pm/packages/graphql_ws_client)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/graphql_ws_client/)\n[![License](https://img.shields.io/hexpm/l/graphql_ws_client.svg)](https://github.com/tlux/graphql_ws_client/blob/main/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/tlux/graphql_ws_client.svg)](https://github.com/tlux/graphql_ws_client/commits/main)\n\nAn extensible client for connecting with GraphQL over Websockets following the\n[graphql-ws](https://github.com/enisdenjo/graphql-ws) conventions.","ref":"readme.html"},{"type":"extras","title":"Installation - Readme","doc":"The package can be installed by adding `graphql_ws_client` to your list of\ndependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:graphql_ws_client, \"~> 2.0\"},\n  ]\nend\n```\n\nIf you are using the default configuration, `GraphQLWSClient.Drivers.Gun` is\nused as driver and you will need the `gun` and `jason` packages as well.\n\n```elixir\ndef deps do\n  [\n    # ...\n    {:gun, \"~> 2.1\"},\n    {:jason, \"~> 1.4\"},\n  ]\nend\n```\n\nTake a\nlook in the driver documentation to find out how to customize driver options.\n\nAlternatively, you can write your own driver based on the\n`GraphQLWSClient.Driver` behaviour.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Readme","doc":"Connect to a socket:\n\n```elixir\n{:ok, socket} = GraphQLWSClient.start_link(url: \"ws://localhost:4000/socket\")\n```\n\nSend a query or mutation and return the result immediately:\n\n```elixir\n{:ok, result} = GraphQLWSClient.query(socket, \"query GetPost { ... }\")\n```\n\nRegister a subscription to listen for events:\n\n```elixir\n{:ok, subscription_id} = GraphQLWSClient.subscribe(\n  socket,\n  \"subscription PostCreated { ... }\"\n)\n\nGraphQLWSClient.query!(socket, \"mutation CreatePost { ... }\")\n\nreceive do\n  %GraphQLWSClient.Event{type: :error, id: ^subscription_id, payload: error} ->\n    IO.inspect(error, label: \"error\")\n  %GraphQLWSClient.Event{type: :next, id: ^subscription_id, payload: result} ->\n    IO.inspect(result)\n  %GraphQLWSClient.Event{type: :complete, id: ^subscription_id} ->\n    IO.puts(\"Stream closed\")\nend\n\nGraphQLClient.close(socket)\n```\n\nYou would usually put this inside of a custom `GenServer` and handle the events\nin `handle_info/3`.\n\nAlternatively, you can create a stream of results:\n\n```elixir\nsocket\n|> GraphQLWSClient.stream!(\"subscription PostCreated { ... }\")\n|> Stream.each(fn result ->\n  IO.inspect(result)\nend)\n|> Stream.run()\n```","ref":"readme.html#usage"},{"type":"extras","title":"Custom Client - Readme","doc":"If you want to run the client as part of a supervision tree in your\napplication, you can also `use GraphQLWSClient` to create your own client.\n\n```elixir\ndefmodule MyClient do\n  use GraphQLWSClient, otp_app: :my_app\nend\n```\n\nThen, you can configure your client using a config file:\n\n```elixir\nimport Config\n\nconfig :my_app, MyClient,\n  url: \"ws://localhost:4000/socket\"\n```","ref":"readme.html#custom-client"},{"type":"extras","title":"Docs - Readme","doc":"Documentation can be found at   or\ngenerated locally using `mix docs`.","ref":"readme.html#docs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}